#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-web
version:              1.52.1
visibility:           public
id:                   hledger-web-1.52.1-294Nz0ehknEBnsL1RqzMtF
key:                  hledger-web-1.52.1-294Nz0ehknEBnsL1RqzMtF
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Web user interface for the hledger accounting system
description:
    A simple web user interface for the hledger accounting system,
    providing a more modern UI than the command-line or terminal interfaces.
    It can be used as a local single-user UI, or as a multi-user UI for
    viewing\/adding\/editing on the web.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance
abi:                  c08143290ae715d82ad420cf9858b7e4
exposed:              True
exposed-modules:
    Hledger.Web Hledger.Web.App Hledger.Web.Application
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Main Hledger.Web.Settings
    Hledger.Web.Settings.StaticFiles Hledger.Web.Test
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common

hidden-modules:       Paths_hledger_web
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-web
hs-libraries:         HShledger-web-1.52.1-294Nz0ehknEBnsL1RqzMtF
depends:
    Decimal-0.5.2-53XVb6O9fE66SQmvUAIDzC
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR base-4.18.2.1
    base64-1.0-8RUOs9Pxm8T8VVdBxgy7HW
    blaze-html-0.9.2.0-PSPLizehIBK0KyrDun70k
    blaze-markup-0.8.3.0-En1LhSl79346pvouIeUq7J bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Gzh99I2Ds5LB1yZuFXcZ2A
    clientsession-0.9.3.0-4NDwZs0AqJiGIrIryCYfmy
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    conduit-1.3.6.1-F67YktQmHRqJ5R9QX7ucHV
    conduit-extra-1.3.8-6O6CtrkaMBHHbx4pVlP0Hf containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-1gq06OiTdkG7AFSCXWttYR
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    githash-0.1.7.0-KXpxlnNxnilFkvYWOdjlnx
    hjsmin-0.2.1-2gGfXeOvuhcXIdPMAedMy
    hledger-1.52.1-GuzeuA0n113IqNhRaF1CcM
    hledger-lib-1.52.1-7O9MQE0QEC49ycuf9c6eXU
    hspec-2.11.6-E0uhxHffRSN1j3XWX1A6LR
    http-client-0.7.19-ChmOISdzz1UJcIMHPfAR81
    http-conduit-2.3.9.1-5Jfl4K985Op1AUK3YAkGuJ
    http-types-0.12.4-LSgWFg4mVle7jKIO2vdgXi
    megaparsec-9.7.0-HsgXVXUZbtJGVbAzhzLwYB mtl-2.3.1
    network-3.1.4.0-435zy6qxTBGFK5XFFiJsye
    safe-0.3.21-GLTVOu0sarW6Z7N465j1G9
    shakespeare-2.1.7.1-IabZuHrxNmOG3MOVpkDAJn
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-BZMXqomGfYu4rulQDFCFZv
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    wai-3.2.4-7vzMwDkBBVH69wuxH7kNR
    wai-cors-0.2.7-DZHnTTmGUFb4wWV7I3SVTf
    wai-extra-3.1.18-FkJl3fQujq328X4evuCipJ
    wai-handler-launch-3.0.3.1-KeZJ8r5LR3BFiECzXEYRwk
    warp-3.4.0-9drghNnWwGm1mQJPNiEMEP
    yaml-0.11.11.2-KqhXgUc3VA7C1IL3BQ5ruQ
    yesod-1.6.2.1-D7kNPN0B532IHbocZbYbS1
    yesod-core-1.6.28.0-AMLfS4ptXbq7Y8NcdaatBG
    yesod-form-1.7.9.3-50vTHI8ZUK53Vh2LeU1DRR
    yesod-static-1.6.1.2-CiKqH0csUu1EJ7KoXnDu30
    yesod-test-1.6.23-FZTXV9qShmY1CbxfF0dAQG

haddock-interfaces:   /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html:         /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

